@@ -1,4 +1,4 @@
-use actix_http::{BoxedPayloadStream, encoding::Decoder, Payload};
+use actix_http::BoxedPayloadStream;
 use awc::{ClientResponse, error::SendRequestError as AwcError};
 
 use super::Asserhttp;
@@ -7,7 +7,7 @@ mod status;
 mod header;
 mod body;
 
-pub type AwcResponse = ClientResponse<Decoder<Payload<BoxedPayloadStream>>>;
+pub type AwcResponse = ClientResponse<BoxedPayloadStream>;
 
 impl Asserhttp<AwcResponse> for AwcResponse {}
 
